#
# spec file for package libwmf
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define lname	libwmf-0_2-7
Name:           libwmf
Version:        0.2.13
Release:        1.9
Summary:        Utilities for Displaying and Converting Metafile Images
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/caolanm/libwmf
Source:         https://github.com/caolanm/libwmf/archive/v%{version}.tar.gz
Source2:        baselibs.conf
Patch1:         libwmf-0.2.8.4-fix.patch
Patch4:         libwmf-0.2.8.4-gd_libpng.patch
Patch5:         libwmf-0.2.8.4-bnc495842.patch
BuildRequires:  gd-devel
BuildRequires:  gtk2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)
Provides:       mswordvw:%{_bindir}/wmftopng
Provides:       wv:%{_bindir}/wmftopng

%description
This library interprets metafile images and can either display them
using the X Window System or convert them to standard formats such as
PNG, JPEG, PS, EPS, and more.

%package tools
Summary:        Utilities for Displaying and Converting Metafile Images
# Prov/Obs added on 2011-11-22 (post openSUSE 12.1)
Group:          Productivity/Graphics/Other
Provides:       libwmf = %{version}-%{release}
Provides:       wmf-utils = %{version}-%{release}
Obsoletes:      libwmf < %{version}-%{release}
Obsoletes:      wmf-utils < %{version}-%{release}

%description tools
These utilities read metafile images and can either display them
using the X Window System or convert them to standard formats such as
PNG, JPEG, PS, EPS, and more.

%package -n %{lname}
Summary:        Library for reading Metafile Images
Group:          System/Libraries

%description -n %{lname}
This library reads metafile images.

%package devel
Summary:        Static libraries, header files and documentation for libwmf
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libwmf-gnome = %{version}
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xproto)
Requires:       pkgconfig(zlib)
Provides:       mswordvd:%{_prefix}/lib/libwmf.a
Provides:       wv-devel:%{_prefix}/lib/libwmf.a

%description devel
The libwmf-devel package contains the header files and static libraries
necessary for developing programs using libwmf.

%package gnome
Summary:        GNOME plugin for displaying and Converting Metafile Images
Group:          System/Libraries

%description gnome
This library interprets metafile images and can either display them
using the X Window System or convert them to standard formats such as
PNG, JPEG, PS, EPS, and more.

%prep
%setup -q
%autopatch -p0

%build
%configure \
    --disable-static \
    --enable-magick \
    $RPM_ARCH-suse-linux
%make_build

%install
%make_install wmfdocdir=%{_defaultdocdir}/libwmf \
     wmfonedocdir=%{_defaultdocdir}/libwmf/caolan
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files tools
%license COPYING
%doc AUTHORS CREDITS README TODO
%{_bindir}/libwmf-fontmap
%{_bindir}/wmf2eps
%{_bindir}/wmf2fig
%{_bindir}/wmf2gd
%{_bindir}/wmf2svg
%{_bindir}/wmf2x
%{_datadir}/libwmf

%files -n %{lname}
%{_libdir}/libwmf*-0.2.so.7*

%files gnome
%{_libdir}/gdk-pixbuf-*/*/loaders/*.so

%files devel
%doc doc/caolan
%doc doc/html
%doc doc/*.{html,png,gif}
%{_bindir}/libwmf-config
%{_includedir}/libwmf
%{_libdir}/libwmf*.so
%{_libdir}/pkgconfig/libwmf.pc

%changelog
* Thu Apr 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.13:
  * new release with various fixes
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.2.12:
  * upstream changed to fork from Fedora: https://github.com/caolanm/libwmf
  * fix abi
  * merge in fixes for libgd CVE-2019-6978
  * release with coverity, clang and shellcheck fixes
  * Seeing as wvware.sourceforge.net seems to be dead, but libwmf is still in
    use and has had a bunch of security bugs reported against, and I've a
    history with libwmf, I'll call this libwmf 0.2.9 and merge in my (Red Hat)
    fixes.
- drop libwmf-0.2.8.4-ia64.patch, libwmf-0.2.8.4-config.patch: obsolete
- drop libwmf-0.2.8.4-overflow-CVE-2006-3376.patch: upstream via
  https://github.com/caolanm/libwmf/commit/b9cc022c8d7dd8c557e2dae5681c2d344237b4f9
- drop libwmf-0.2.8.4-CVE-2015-0848.patch: part of
  https://github.com/caolanm/libwmf/commit/879d6bffa6dd21b8c0e9ec3b5aa31b6ae090ef83
- drop libwmf-0.2.8.4-badrle.patch: part of
  https://github.com/caolanm/libwmf/commit/879d6bffa6dd21b8c0e9ec3b5aa31b6ae090ef83
- drop libwmf-0.2.8.4-CVE-2015-4696.patch: upstream via
  https://github.com/caolanm/libwmf/commit/f47cbdf96838c2daa7b8e489f59e62371d33352a
- drop libwmf-0.2.8.4-CVE-2015-4695.patch: upstream via
  https://github.com/caolanm/libwmf/commit/b5ae5d1f3bbddf051a5c9dd01897bd835817f013
- drop reproducible.patch: differently done upstream
- drop use-pkg-config-for-freetype.patch: obsolete
* Mon Aug 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Fri May  4 2018 idonmez@suse.com
- Add use-pkg-config-for-freetype.patch to use pkgconfig to detect
  Freetype libraries. Add BR autoconf, automake, libtool due to
  above.
* Tue Mar 13 2018 crrodriguez@opensuse.org
- libwmf-0.2.8.4-config.patch: update so -config --libs
  do not inject bogus dependencies to other packages.
- build with disable-static too.
* Thu Mar  1 2018 crrodriguez@opensuse.org
- Fix -devel package Requires not to still include xorg-x11-devel
* Mon Jan 29 2018 sndirsch@suse.com
- removed unneeded 'BuildRequires: xorg-x11-util-devel' (bsc#1077489)
* Tue Jun 20 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible (boo#1041090)
* Tue Jun 30 2015 fstrba@suse.com
- Added patches:
  * libwmf-0.2.8.4-CVE-2015-4695.patch
  - Fix CVE-2015-4695: meta_pen_create heap buffer over read
    (bsc#936058)
  * libwmf-0.2.8.4-CVE-2015-4696.patch
  - Fix CVE-2015-4696: wmf2gd/wmf2eps use after free (bsc#936062)
* Thu Jun 11 2015 fstrba@suse.com
- Added patches:
  * libwmf-0.2.8.4-CVE-2015-0848.patch
  - Fix CVE-2015-0848: Heap overflow on libwmf0.2-7 (bsc#933109)
  * libwmf-0.2.8.4-badrle.patch
  - Fix CVE-2015-4588: DecodeImage() does not check that the
    run-length "count" fits into the total size of the image,
    which can lead to a heap-based buffer overflow (bsc#933109)
* Wed Aug 20 2014 nadvornik@suse.com
- dropped libwmf-devel -> libwmf-tools dependency (bnc#892356)
* Wed May 28 2014 fstrba@suse.com
- Clean spec file with spec-cleaner
- Do not distribute *.la files
* Wed Mar  5 2014 nadvornik@suse.com
- Add libwmf-0.2.8.4-bnc495842.patch to fix realloc return value
  usage (bnc#495842, bnc#831299)
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Jun 18 2012 dimstar@opensuse.org
- Add libwmf-0_2-7 to baselibs.conf.
* Sat Mar  3 2012 jengelh@medozas.de
- Add libjpeg-devel as BuildRequires, needed to resolve build error
- Add selected Xorg packages to BR to have wmf2x be built again
* Mon Jan 30 2012 jengelh@medozas.de
- Remove further redundant sections
* Tue Nov 29 2011 jengelh@medozas.de
- Actually use "libwmf-tools" instead of wmf-utils, this goes much
  more in line with the preexisting libwpd-tools and libwps-tools.
* Tue Nov 15 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Apply shlib packaging (-> new libwmf-0_2-7 subpackage),
  create "wmf-utils" subpackage as suggested by namtrac
* Fri Dec 17 2010 coolo@novell.com
- fix file list
* Sun Apr  4 2010 ro@suse.de
- fix build of in-tree copy of gd to build with new libpng14
  (long deprecated function has been removed)
* Thu Dec 24 2009 jengelh@medozas.de
- package baselibs.conf
- enable parallel build
* Mon Dec 21 2009 coolo@novell.com
- rediff another patch
* Tue Dec  8 2009 meissner@suse.de
- rediffed without fuzz, some spec cleanups
* Tue Nov 25 2008 sbrabec@suse.cz
- Supplement gtk2-32bit/gtk2-64bit in baselibs.conf (bnc#354164).
* Tue Jan 16 2007 nadvornik@suse.cz
- changed gnome prefix to /usr
* Thu Aug 24 2006 cthiel@suse.de
- fix build
* Tue Aug 22 2006 nadvornik@suse.cz
- branched libwmf-gnome subpackage [#195613]
* Wed Jul 12 2006 nadvornik@suse.cz
- fixed integer overflow [CVE-2006-3376. #189924]
* Tue Jun 27 2006 nadvornik@suse.cz
- updated to bugfix release 0.2.8.4
  * fixes various compiler warnings [#185398]
* Thu Jan 26 2006 nadvornik@suse.cz
- fixed undefined code [#136822]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Tue Sep 20 2005 nadvornik@suse.cz
- fixed uninitialized variables and missing includes
* Tue Jul 26 2005 nadvornik@suse.cz
- fixed devel requirements [#98131]
* Mon Apr  4 2005 nadvornik@suse.cz
- fixed more missing return values
* Mon Apr 19 2004 nadvornik@suse.cz
- fixed missing return values
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Wed Jan  7 2004 nadvornik@suse.cz
- updated to 0.2.8.2 to build with new freetype
* Thu Jul 31 2003 ro@suse.de
- move gtk-stuff to /opt/gnome
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jun 16 2003 sbrabec@suse.cz
- Updated to version 0.2.8.
- Updated neededforbuild and %%files.
* Thu May 29 2003 nadvornik@suse.cz
- packaged html documentation
* Tue Sep 10 2002 pthomas@suse.de
- Change libwmf-config to omit /usr/include from output.
* Tue Sep  3 2002 nadvornik@suse.cz
- fixed crash with ImageMagick
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Thu Jun 20 2002 nadvornik@suse.cz
- update to 0.2.6
* Mon Apr 29 2002 nadvornik@suse.cz
- used macro %%{_libdir}
* Wed Mar 13 2002 nadvornik@suse.cz
- added /usr/share/doc/packages/libwmf to filelist
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Nov 28 2001 nadvornik@suse.cz
- update to 0.2.2:
  - the .fig export uses scaling now, and has options to save images
    as PNG or JPEG
  - the .svg export now supports inline images and compression to .svgz
  - a slight change in the API
* Thu Jun 28 2001 nadvornik@suse.cz
- splited from wv
- update to 0.2.0
